==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-time/lxqt-admin-time_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DateTime</name>
    <message>
        <source>Form</source>
        <translation type="vanished">フォーム</translation>
    </message>
    <message>
        <source>Time and date setup</source>
        <translation type="vanished">日時設定</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>日付</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;変更の保存には管理権限が必要です。&lt;br&gt;閉じるボタンを押した直後に要求されるでしょう。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>日時設定</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="53"/>
        <source>Date and time</source>
        <translation>日時</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="62"/>
        <source>Timezone</source>
        <translation>タイムゾーン</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="162"/>
        <source>Authentication Error</source>
        <translation>認証エラー</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <source>Form</source>
        <translation type="vanished">フォーム</translation>
    </message>
    <message>
        <source>Timezone setup</source>
        <translation type="vanished">タイムゾーン設定</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>現在のタイムゾーン</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="54"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;変更の保存には管理権限が必要です。&lt;br&gt;閉じるボタンを押した直後に要求されるでしょう。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-time/lxqt-admin-time_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DateTime</name>
    <message>
        <source>Form</source>
        <translation type="vanished">フォーム</translation>
    </message>
    <message>
        <source>Time and date setup</source>
        <translation type="vanished">日時設定</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>日付:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>ネットワークによる時刻の同期を可能にする(NTP)</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTCはローカル時刻です</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;変更の保存には管理権限が必要です。&lt;br&gt;閉じるボタンを押した直後に要求されるでしょう。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>日時設定</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="48"/>
        <source>Date and time</source>
        <translation>日時</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="56"/>
        <source>Timezone</source>
        <translation>タイムゾーン</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="117"/>
        <location filename="../../../timeadmindialog.cpp" line="127"/>
        <location filename="../../../timeadmindialog.cpp" line="134"/>
        <location filename="../../../timeadmindialog.cpp" line="144"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Authentication Error</source>
        <translation type="vanished">認証エラー</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <source>Form</source>
        <translation type="vanished">フォーム</translation>
    </message>
    <message>
        <source>Timezone setup</source>
        <translation type="vanished">タイムゾーン設定</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>現在のタイムゾーン:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;変更の保存には管理権限が必要です。&lt;br&gt;閉じるボタンを押した直後に要求されるでしょう。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">なし</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
</context>
</TS>
